@@ -10,6 +10,7 @@ from python_kemptech_api.api_xml import (
     get_data_field,
     is_successful,
     get_data,
+    parse_to_dict,
     get_error_msg
 )
 from python_kemptech_api.capabilities import CAPABILITIES, DEFAULT
@@ -1398,7 +1399,11 @@ class LoadMaster(BaseKempAppliance):
         # x variables are the object while x_data is the OrderedDict
         virtual_services = []
         response = self._get("/listvs")
-        data = get_data(response)
+        # build_virtual_service's response parameter
+        # must be a full response dict for regular VS
+        # and the Data portion of response dict for sub VS
+        parsed_resp = parse_to_dict(response)
+        data = get_data(parsed_resp)
         virtual_services_data = data.get('VS', [])
         virtual_services_data = cast_to_list(virtual_services_data)
 
@@ -1412,7 +1417,7 @@ class LoadMaster(BaseKempAppliance):
                         virt_serv = self.build_virtual_service(service_data,
                                                                vs)
             else:
-                virt_serv = self.build_virtual_service(service_data, data)
+                virt_serv = self.build_virtual_service(service_data, parsed_resp)
             real_servers = cast_to_list(service_data.get("Rs", []))
             for server_data in real_servers:
                 rs = virt_serv.build_real_server(server_data)
